package com.ym.service;

import io.rong.models.Result;
import io.rong.models.conversation.ConversationModel;
import io.rong.models.group.GroupModel;
import io.rong.models.group.UserGroup;

public interface GroupService {

    //群组模块   群组
    Result groupSync(UserGroup userGroup) throws Exception;

    Result groupCreate(GroupModel groupModel) throws Exception;

    Result groupGet(GroupModel groupModel) throws Exception;

    Result groupUpdate(GroupModel groupModel) throws Exception;

    Result groupJoin(GroupModel groupModel) throws Exception;

    Result groupQuit(GroupModel groupModel) throws Exception;

    Result groupDismiss(GroupModel groupModel) throws Exception;


    //成员禁言
    Result muteMembersAdd(GroupModel groupModel) throws Exception;

    Result muteMembersRemove(GroupModel groupModel) throws Exception;

    Result muteMembersGetList(String groupId) throws Exception;


    //整体禁言
    Result muteAllMembersAdd(String[] groupIds) throws Exception;

    Result muteAllMembersRemove(String[] groupIds) throws Exception;

    Result muteAllMembersGetList() throws Exception;


    //群禁言用户白名单服务
    Result muteWhiteAdd(GroupModel groupModel) throws Exception;

    Result muteWhiteRemove(GroupModel groupModel) throws Exception;

    Result muteWhiteGetList(String groupId) throws Exception;



    //会话模块   会话
    Result conversationMute(ConversationModel conversationModel) throws Exception;

    Result conversationUnmute(ConversationModel conversationModel) throws Exception;
}
